summaryrefslogtreecommitdiffstats
path: root/src/playbackoptionsw.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/playbackoptionsw.cpp')
-rw-r--r--src/playbackoptionsw.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/playbackoptionsw.cpp b/src/playbackoptionsw.cpp
index 66de7d4..56b0f43 100644
--- a/src/playbackoptionsw.cpp
+++ b/src/playbackoptionsw.cpp
@@ -100,11 +100,11 @@ static const unsigned char img0_playbackoptionsw[] = {
/*
* Constructs a PlaybackOptionsw as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-PlaybackOptionsw::PlaybackOptionsw( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+PlaybackOptionsw::PlaybackOptionsw( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
TQImage img;
img.loadFromData( img0_playbackoptionsw, sizeof( img0_playbackoptionsw ), "PNG" );
@@ -100,11 +100,11 @@ static const unsigned char img0_playbackoptionsw[] = {
/*
- * Constructs a PlaybackOptionsw as a child of 'tqparent', with the
+ * Constructs a PlaybackOptionsw as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/